[cfe-commits] r102168 - /cfe/trunk/lib/CodeGen/Mangle.cpp

Douglas Gregor dgregor at apple.com
Thu Apr 22 20:19:53 PDT 2010


Author: dgregor
Date: Thu Apr 22 22:19:53 2010
New Revision: 102168

URL: http://llvm.org/viewvc/llvm-project?rev=102168&view=rev
Log:
Emit a lame diagnostic when we can't mangle operator names

Modified:
    cfe/trunk/lib/CodeGen/Mangle.cpp

Modified: cfe/trunk/lib/CodeGen/Mangle.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/CodeGen/Mangle.cpp?rev=102168&r1=102167&r2=102168&view=diff
==============================================================================
--- cfe/trunk/lib/CodeGen/Mangle.cpp (original)
+++ cfe/trunk/lib/CodeGen/Mangle.cpp Thu Apr 22 22:19:53 2010
@@ -767,7 +767,11 @@
   if (Dependent->isIdentifier())
     mangleSourceName(Dependent->getIdentifier());
   else {
-    // FIXME: We can't possibly know the arity for mangling operators!
+    // FIXME: We can't possibly know the arity of the operator here!
+    Diagnostic &Diags = Context.getDiags();
+    unsigned DiagID = Diags.getCustomDiagID(Diagnostic::Error,
+                                 "cannot mangle dependent operator name");
+    Diags.Report(FullSourceLoc(), DiagID);
   }
 }
 





More information about the cfe-commits mailing list